Introduction
============

.. image:: https://badge.fury.io/py/wa-kat.png
    :target: https://pypi.python.org/pypi/wa-kat

.. image:: https://img.shields.io/pypi/dm/wa-kat.svg
    :target: https://pypi.python.org/pypi/wa-kat

.. image:: https://readthedocs.org/projects/wa-kat/badge/?version=latest
    :target: http://wa-kat.readthedocs.org/

.. image:: https://img.shields.io/github/issues/WebArchivCZ/WA-KAT.svg
    :target: https://github.com/WebArchivCZ/WA-KAT/issues

.. image:: https://img.shields.io/pypi/l/wa-kat.svg

WA-KAT is a project that simplifies the job of curators of the Webarchive of National Library of the Czech Republic by cataloging electronic resources using semi-automatic analysis.

Documentation
-------------

Module documentation and description can be found at Read the Docs:

- http://wa-kat.readthedocs.org
